@@ -1,7 +1,5 @@
 # frozen_string_literal: true
 
-require 'redis-client'
-
 class Redis
   class Client < ::RedisClient
     ERROR_MAPPING = {
@@ -17,6 +15,9 @@ class Redis
       RedisClient::ProtocolError => Redis::ProtocolError,
       RedisClient::OutOfMemoryError => Redis::OutOfMemoryError,
     }
+    if defined?(RedisClient::NoScriptError)
+      ERROR_MAPPING[RedisClient::NoScriptError] = Redis::NoScriptError
+    end
 
     class << self
       def config(**kwargs)
@@ -86,6 +87,12 @@ class Redis
     undef_method :call_once_v
     undef_method :blocking_call
 
+    def ensure_connected(retryable: true, &block)
+      super(retryable: retryable, &block)
+    rescue ::RedisClient::Error => error
+      Client.translate_error!(error)
+    end
+
     def call_v(command, &block)
       super(command, &block)
     rescue ::RedisClient::Error => error
