@@ -114,7 +114,7 @@ module Lint
         assert_equal ["f1", "f2"], r.hrandfield("foo", 2).sort
         assert_equal 4, r.hrandfield("foo", -4).size
 
-        r.hrandfield("foo", 2, with_values: true) do |(field, value)|
+        r.hrandfield("foo", 2, with_values: true).each do |(field, value)|
           assert ["f1", "f2"].include?(field)
           assert ["s1", "s2"].include?(value)
         end
